@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2016-2018 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of Django-Mailman.
 #
@@ -20,8 +20,6 @@
 # Author: Aurelien Bompard <abompard@fedoraproject.org>
 #
 
-
-
 from django.apps import AppConfig
 
 
@@ -30,4 +28,4 @@ class DjangoMailman3Config(AppConfig):
     verbose_name = "Django Mailman 3"
 
     def ready(self):
-        import django_mailman3.signals  # flake8: noqa
+        import django_mailman3.signals  # noqa: F401
