@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2016-2018 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of Django-Mailman.
 #
@@ -21,12 +21,10 @@
 #
 
 
+from unittest.mock import Mock
+
 from django.contrib.auth.models import User
-try:
-    from django.core.urlresolvers import reverse
-except ImportError:
-    from django.urls import reverse
-from mock import Mock
+from django.urls import reverse
 
 from django_mailman3.models import Profile
 from django_mailman3.tests.utils import TestCase
